@@ -5,17 +5,24 @@
 #' @exportMethod as.VCorpus
 #' @rdname as.VCorpus
 #' @examples
-#' \dontrun{
-#' use("polmineR.sampleCorpus")
-#' P <- partition("PLPRBTTXT", text_date = "2009-11-10")
-#' PB <- partitionBundle(P, sAttribute = "text_speaker")
+#' use("polmineR")
+#' P <- partition("GERMAPARLMINI", date = "2009-11-10")
+#' PB <- partitionBundle(P, sAttribute = "speaker")
 #' VC <- as.VCorpus(PB)
-#' }
 setMethod("as.VCorpus", "partitionBundle", function(x){
+  sAttrLengths <- sapply(sAttributes(x@objects[[1]]@corpus), function(sAttr) CQI$attribute_size(x@objects[[1]]@corpus, sAttr, type = "s"))
+  if (length(unique(sAttrLengths)) == length(sAttrLengths)){
+    sAttrToGet <- sAttributes(x@objects[[1]]@corpus)
+  } else {
+    message("Using only the s-attributes that have the same length as the s-attribute in the slot sAttributeStrucs ",
+            "of the first partition")
+    sAttrToGet <- names(sAttrLengths[which(sAttrLengths == sAttrLengths[x@objects[[1]]@sAttributeStrucs])])
+  }
+  
   content <- blapply(
     x@objects,
     function(P){
-      metadata <- sapply(sAttributes(P), function(sAttr) sAttributes(P, sAttr)[1])
+      metadata <- sapply(sAttrToGet, function(sAttr) sAttributes(P, sAttr)[1])
       class(metadata) <- "TextDocumentMeta"
       doc <- list(
         meta = metadata,
