@@ -5,9 +5,6 @@
 #' @rdname pAttribute-method
 setGeneric("pAttribute", function(object) standardGeneric("pAttribute"))
 
-#' @exportMethod dissect
-setGeneric("dissect", function(object, ...) standardGeneric("dissect"))
-
 #' @exportMethod name
 #' @rdname polmineR-generics
 setGeneric("name", function(x) standardGeneric("name"))
