@@ -1,41 +1,39 @@
 #' @include partition_class.R 
 NULL
 
-setGeneric("sAttributes", function(.Object, ...){standardGeneric("sAttributes")})
+setGeneric("sAttributes", function(.Object, ...) standardGeneric("sAttributes"))
 
 
 #' @param unique logical, whether to return unique values only
 #' @param regex filter return value by applying a regex
 #' @rdname sAttributes-method
 setMethod("sAttributes", "character", function(.Object, sAttribute = NULL, unique = TRUE, regex = NULL){
+  if (!.Object %in% CQI$list_corpora()) stop("corpus name provided not available")
+  
   if (is.null(sAttribute)){
-    return(CQI$attributes(.Object, "s"))
+    return( CQI$attributes(.Object, "s") )
   } else {
-    if (.Object %in% CQI$list_corpora()) {
-      if (length(sAttribute) == 1){
-        ret <- CQI$struc2str(
-          .Object, sAttribute,
-          c(0:(CQI$attribute_size(.Object, sAttribute, type = "s")-1))
-        )
-        if (!is.null(regex)) ret <- grep(regex, ret, value = TRUE)
-        if (unique == TRUE) ret <- unique(ret)
-        Encoding(ret) <- getEncoding(.Object)
-        return(ret)
-      } else if (length(sAttribute) > 1){
-        corpusEncoding <- RegistryFile$new(.Object)$getEncoding()
-        metaInformation <- lapply(
-          sAttribute,
-          function(x) {
-            retval <- CQI$struc2str(.Object, x, 0:(CQI$attribute_size(.Object, x, "s")-1))
-            Encoding(retval) <- corpusEncoding
-            as.nativeEnc(retval, from = corpusEncoding)
-          })
-        names(metaInformation) <- sAttribute
-        return( as.data.table(metaInformation) )
-      }
-    } else {
-      warning("corpus name provided not available")
-      return(NULL)
+    if (length(sAttribute) == 1){
+      ret <- CQI$struc2str(
+        .Object, sAttribute,
+        0:(CQI$attribute_size(.Object, sAttribute, type = "s") - 1)
+      )
+      if (!is.null(regex)) ret <- grep(regex, ret, value = TRUE)
+      if (unique) ret <- unique(ret)
+      Encoding(ret) <- getEncoding(.Object)
+      ret <- as.nativeEnc(ret, from = getEncoding(.Object))
+      return(ret)
+    } else if (length(sAttribute) > 1){
+      corpusEncoding <- registry_get_encoding(.Object)
+      metaInformation <- lapply(
+        sAttribute,
+        function(x) {
+          retval <- CQI$struc2str(.Object, x, 0:(CQI$attribute_size(.Object, x, "s") - 1))
+          Encoding(retval) <- corpusEncoding
+          as.nativeEnc(retval, from = corpusEncoding)
+        })
+      names(metaInformation) <- sAttribute
+      return( as.data.table(metaInformation) )
     }
   }
 })
@@ -64,34 +62,38 @@ setMethod("sAttributes", "character", function(.Object, sAttribute = NULL, uniqu
 #' @aliases sAttributes sAttributes,character-method sAttributes,partition-method
 #' @rdname sAttributes-method
 #' @examples 
-#' \dontrun{
-#'   use("polmineR.sampleCorpus")
+#'   use("polmineR")
 #'   
-#'   sAttributes("PLPRBTTXT")
-#'   sAttributes("PLPRBTTXT", "text_date") # dates of plenary meetings
+#'   sAttributes("GERMAPARLMINI")
+#'   sAttributes("GERMAPARLMINI", "date") # dates of plenary meetings
 #'   
 #'   
-#'   P <- partition("PLPRBTTXT", text_date = "2009-11-10")
+#'   P <- partition("GERMAPARLMINI", date = "2009-11-10")
 #'   sAttributes(P)
-#'   sAttributes(P, "text_name") # get names of speakers
-#' }
+#'   sAttributes(P, "speaker") # get names of speakers
 setMethod(
   "sAttributes", "partition",
-  function (.Object, sAttribute = NULL) {
+  function (.Object, sAttribute = NULL, unique = TRUE) {
     if (is.null(sAttribute)){
       return( CQI$attributes(.Object@corpus, "s") )
     } else {
       if (length(sAttribute) == 1){
         if (.Object@xml == "flat" || .Object@sAttributeStrucs == sAttribute){
-          retval <- unique(CQI$struc2str(.Object@corpus, sAttribute, .Object@strucs));
-          Encoding(retval) <- .Object@encoding;  
+          len1 <- CQI$attribute_size(.Object@corpus, .Object@sAttributeStrucs)
+          len2 <- CQI$attribute_size(.Object@corpus, sAttribute)
+          if (len1 != len2){
+            stop("XML is stated to be flat, but sAttributeStrucs hat length ", len1, " and sAttribute length ", len2)
+          }
+          retval <- CQI$struc2str(.Object@corpus, sAttribute, .Object@strucs)
+          if (unique) retval <- unique(retval)
         } else {
           cposVector <- unlist(apply(.Object@cpos, 1, function(x) x[1]:x[2]))
           strucs <- CQI$cpos2struc(.Object@corpus, sAttribute, cposVector)
           retval <- CQI$struc2str(.Object@corpus, sAttribute, strucs)
-          retval <- unique(retval)
-          Encoding(retval) <- .Object@encoding
+          if (unique) retval <- unique(retval)
         }
+        Encoding(retval) <- .Object@encoding
+        retval <- as.nativeEnc(retval, from = .Object@encoding)
         return(retval)
       } else if (length(sAttribute) > 1){
         if (.Object@xml == "flat") {
@@ -102,7 +104,7 @@ setMethod(
               function(x) { 
                 tmp <- CQI$struc2str(.Object@corpus, x, .Object@strucs)
                 Encoding(tmp) <- .Object@encoding
-                tmp
+                as.nativeEnc(tmp, from = .Object@encoding)
               }
             ),
             stringsAsFactors = FALSE
@@ -116,7 +118,7 @@ setMethod(
               function(x) {
                 tmp <- CQI$struc2str(.Object@corpus, x, CQI$cpos2struc(.Object@corpus, x, .Object@cpos[,1]))
                 Encoding(tmp) <- .Object@encoding
-                tmp
+                as.nativeEnc(tmp, from = .Object@encoding)
               }
             )
           )
