@@ -7,17 +7,26 @@
 #' @param ... further parameters
 setGeneric("view", function(.Object, ...) standardGeneric("view"))
 
-#' @rdname partition-class
+#' @rdname partition_class
 setMethod("view", "partition", function(.Object){
   tableToView <- .Object@stat
-  View(tableToView)
+  get("View", envir = .GlobalEnv)(tableToView)
 })
 
 
-#' @rdname partition-class
+#' @rdname partition_class
 setMethod("view", "cooccurrences", function(.Object){
-  tableToView <- .Object@stat
-  View(tableToView)
+  if ("count_partition" %in% colnames(.Object))
+    attr(.Object@stat[["count_partition"]], "label") <- "observed in partition"
+  if ("count_window" %in% colnames(.Object))
+    attr(.Object@stat[["count_window"]], "label") <- "observed in window"
+  if ("exp_window" %in% colnames(.Object))
+    attr(.Object@stat[["exp_window"]], "label") <- "expected in window"
+  if ("exp_partition" %in% colnames(.Object))
+    attr(.Object@stat[["exp_partition"]], "label") <- "expected in partition"
+  if ("ll" %in% colnames(.Object)) attr(.Object@stat[["ll"]], "label") <- "log likelihood"
+  if ("rank_ll" %in% colnames(.Object)) attr(.Object@stat[["rank_ll"]], "label") <- "rank"
+  get("View", envir = .GlobalEnv)(.Object@stat)
 })
 
 
@@ -26,30 +35,15 @@ setMethod("view", "cooccurrences", function(.Object){
 #' @param .Object a kwic object
 setMethod("view", "kwic", function(.Object){
   tableToView <- .Object@table
-  View(tableToView)
+  get("View", envir = .GlobalEnv)(tableToView)
 })
 
 #' @rdname textstat-class
 setMethod("view", "textstat", function(.Object){
   .Object <- round(.Object, digits = 3)
-  View(.Object@stat)
+  get("View", envir = .GlobalEnv)(.Object@stat)
 })
 
-# setMethod("view", "partition", function(.Object){
-#   View(.Object@stat)
-# })
-
-#' @rdname context-class
-setMethod("view", "context", function(.Object){
-  .Object <- round(.Object, 2)
-  whatToView <- c(
-    paste("rank", .Object@method, sep="_"),
-    .Object@pAttribute,
-    "count_window", "count_partition", "exp_window",
-    .Object@method
-    )
-  View(.Object@stat[, whatToView, with=FALSE], title=.Object@query)
-})
 
 #' @exportMethod view
 #' @rdname features-class
@@ -61,12 +55,12 @@ setMethod("view", "features", function(.Object){
     "count_coi", "count_ref", "exp_coi",
     .Object@method
   )
-  View(.Object@stat[, whatToView, with=FALSE], title = "features")
+  get("View", envir = .GlobalEnv)(.Object@stat[, whatToView, with=FALSE], title = "features")
 })
 
 #' @rdname cooccurrences-class
 setMethod(view, "cooccurrencesReshaped", function(.Object){
   .Object <- round(.Object, digits=2)
   colsToView <- c("a", "b", "count_ab", "count_a", "count_b", "ll_a2b", "ll_b2a")
-  View(.Object@stat[, colsToView, with=FALSE])
+  get("View", envir = .GlobalEnv)(.Object@stat[, colsToView, with=FALSE])
 })
